/*
    Copyright (C) 2020 Accurics, Inc.

	Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package helmv3

import "github.com/hashicorp/go-multierror"

// HelmV3 struct implements the IacProvider interface
type HelmV3 struct {
	errIacLoadDirs *multierror.Error
}

type helmChartData map[string]interface{}

const (
	helmValuesFilename = "values.yaml"
	helmTemplateDir    = "templates"
	helmTestDir        = "tests"
)
